@@ -9,6 +9,8 @@ THUMB_URL = (
 DEFAULT_GAME_SIZE = 4
 INVITE_LINK = (
     "https://discordapp.com/api/oauth2/authorize"
-    "?client_id=725510263251402832&permissions=92224&scope=bot"
+    "?client_id=725510263251402832&permissions=93264&scope=bot"
 )
 VOTE_LINK = "https://top.gg/bot/725510263251402832/vote"
+RED_X = "❌"  # emoji red x
+GREEN_CHECK = "✅"  # emoji green check
