@@ -12,6 +12,7 @@ import alembic.config  # type: ignore
 import discord
 from sqlalchemy import (
     BigInteger,
+    Boolean,
     Column,
     DateTime,
     Float,
@@ -22,9 +23,11 @@ from sqlalchemy import (
     and_,
     between,
     create_engine,
+    false,
     func,
     or_,
     text,
+    true,
 )
 from sqlalchemy.engine.base import Connection
 from sqlalchemy.ext.declarative import declarative_base
@@ -48,6 +51,8 @@ class Server(Base):
     prefix = Column(String(10), nullable=False, default="!")
     expire = Column(Integer, nullable=False, server_default=text("30"))  # minutes
     links = Column(String(10), nullable=False, server_default=text("'public'"))
+    power_enabled = Column(Boolean, nullable=False, server_default=true())
+    create_voice = Column(Boolean, nullable=False, server_default=false())
     games = relationship("Game", back_populates="server", uselist=True)
     channels = relationship("Channel", back_populates="server", uselist=True)
     teams = relationship("Team", back_populates="server", uselist=True)
@@ -97,7 +102,7 @@ class Server(Base):
                 "prefix": self.prefix,
                 "expire": self.expire,
                 "channels": [channel.channel_xid for channel in self.channels],
-                "teams": [team.id for team in self.teams],
+                "teams": [team.name for team in self.teams],
             }
         )
 
@@ -296,6 +301,7 @@ class Game(Base):
         String(30), nullable=False, server_default=text("'spelltable'"), index=True
     )
     game_power = Column(Float, nullable=True)
+    voice_channel_xid = Column(BigInteger, nullable=True, index=True)
     users = relationship("User", back_populates="game", uselist=True)
     tags = relationship("Tag", secondary=games_tags, back_populates="games", uselist=True)
     server = relationship("Server", back_populates="games")
@@ -304,6 +310,8 @@ class Game(Base):
 
     @property
     def power(self) -> Optional[float]:
+        if not self.server.power_enabled:
+            return None
         values: List[int] = [user.power for user in self.users if user.power]
         if values:
             return sum(values) / len(values)
@@ -335,14 +343,15 @@ class Game(Base):
             func.count(distinct(games_tags.c.tag_id)) == len(required_tag_ids),
             func.count(distinct(User.xid)) <= size - seats,
         ]
-        if power:
-            having_filters.append(between(func.avg(User.power), power - 1, power + 1))
-            if power >= 7:
-                having_filters.append(func.avg(User.power) >= 7)
+        if server.power_enabled:
+            if power:
+                having_filters.append(between(func.avg(User.power), power - 1, power + 1))
+                if power >= 7:
+                    having_filters.append(func.avg(User.power) >= 7)
+                else:
+                    having_filters.append(func.avg(User.power) < 7)
             else:
-                having_filters.append(func.avg(User.power) < 7)
-        else:
-            select_filters.append(User.power == None)
+                select_filters.append(User.power == None)
         inner = (
             session.query(Game.id)
             .join(User, isouter=True)
@@ -373,13 +382,18 @@ class Game(Base):
             .filter(
                 and_(
                     datetime.utcnow() >= Game.expires_at,
-                    Game.url == None,
-                    Game.status != "ready",
+                    Game.status == "pending",
                 )
             )
             .all(),
         )
 
+    @classmethod
+    def voiced(cls, session: Session) -> List[Game]:
+        return cast(
+            List[Game], session.query(Game).filter(Game.voice_channel_xid != None).all()
+        )
+
     def __repr__(self) -> str:
         return json.dumps(self.to_json())
 
@@ -397,7 +411,9 @@ class Game(Base):
             "system": self.system,
             "message": self.message,
             "message_xid": self.message_xid,
+            "voice_channel_xid": self.voice_channel_xid,
             "tags": [tag.name for tag in self.tags],
+            "event_id": self.event.id if self.event else None,
             "power": self.power,
         }
 
@@ -415,7 +431,6 @@ class Game(Base):
             embed.description = "To join/leave this game, react with ✋/🚫."
         elif self.system == "spelltable":
             if show_link:
-                assert self.url is not None  # TODO: Shouldn't be possible?
                 embed.description = (
                     f"Click the link below to join your SpellTable game.\n<{self.url}>"
                 )
@@ -431,20 +446,28 @@ class Game(Base):
             embed.description = (
                 "Please exchange Arena contact information and head over there to play!"
             )
+        if self.voice_channel_xid:
+            embed.add_field(
+                name="Voice Channel", value=f"<#{self.voice_channel_xid}>", inline=False
+            )
         tag_names = None
         if self.tags and len(cast(List[Tag], self.tags)) >= 1:
             sorted_tag_names: List[str] = sorted([tag.name for tag in self.tags])
             tag_names = ", ".join(sorted_tag_names)
             embed.add_field(name="Tags", value=tag_names)
         power = self.power
-        if power:
+        if power and self.server.power_enabled:
             embed.add_field(name="Average Power Level", value=f"{power:.1f}")
         if self.users:
             players = ", ".join(
                 sorted(
                     [
                         f"<@{user.xid}>"
-                        + (f" (Power: {user.power})" if user.power else "")
+                        + (
+                            f" (Power: {user.power})"
+                            if (user.power and self.server.power_enabled)
+                            else ""
+                        )
                         for user in self.users
                     ]
                 )
